%define pkgsuffix 1.2

%def_without ffmpeg
# X264 backend not implemented, please review your configuration!
%def_without x264
%def_without directfb
# see https://github.com/FreeRDP/FreeRDP/issues/4348
%def_without gss

Name: freerdp%pkgsuffix
Version: 1.2.0
Release: alt2.M80C.1

Group: Networking/Remote access
Summary: Remote Desktop Protocol functionality (compatibility version)
License: Apache-2.0
URL: http://www.freerdp.com
Packager: Andrey Cherepanov <cas@altlinux.org>

Source: freerdp-%version.tar
Patch1: freerdp-cmake-list.patch

Requires: xfreerdp%pkgsuffix = %EVR

BuildRequires(pre): cmake
BuildRequires: gcc-c++
BuildRequires: extra-cmake-modules
BuildRequires: docbook-style-xsl git-core xmlto libpcre-devel
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(libpcsclite)
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(wayland-client)
BuildRequires: pkgconfig(wayland-cursor)
BuildRequires: pkgconfig(wayland-scanner)
BuildRequires: pkgconfig(x11)
BuildRequires: pkgconfig(xcursor)
BuildRequires: pkgconfig(xdamage)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xtst)
BuildRequires: pkgconfig(xi)
BuildRequires: pkgconfig(xinerama)
BuildRequires: pkgconfig(xkbcommon)
BuildRequires: pkgconfig(xkbfile)
BuildRequires: pkgconfig(xrandr)
BuildRequires: pkgconfig(xv)
BuildRequires: pkgconfig(gstreamer-1.0)
BuildRequires: pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires: pkgconfig(libpulse)
%{?_with_directfb:BuildRequires: pkgconfig(directfb)}
BuildRequires: libcups-devel libjpeg-devel zlib-devel
%{?_with_ffmpeg:BuildRequires: libavcodec-devel libavutil-devel libavresample-devel libswresample-devel}
%{?_with_x264:BuildRequires: libx264-devel}
BuildRequires: libkrb5-devel
BuildRequires: wayland-devel
BuildRequires: libmbedtls-devel
BuildRequires: libgsm-devel
BuildRequires: liblame-devel
BuildRequires: libfaad-devel
#BuildRequires: libfaac-devel
BuildRequires: libsoxr-devel
BuildRequires: libffi-devel
BuildRequires: liborc-devel
BuildRequires: libicu-devel
BuildRequires: libcairo-devel
BuildRequires: libpixman-devel
BuildRequires: libexpat-devel
BuildRequires: libXdmcp-devel
BuildRequires: bzlib-devel
BuildRequires: libuuid-devel
BuildRequires: libudev-devel
BuildRequires: libusb-devel
BuildRequires: libdbus-glib-devel

Conflicts: freerdp

%description
freerdp implements Remote Desktop Protocol (RDP), used in a number of Microsoft
products. Rdesktop analog.

This is metapackage.

%package -n xfreerdp%pkgsuffix
Summary: Remote Desktop Protocol client (compatibility version)
Group: Networking/Remote access
Requires: lib%name = %EVR
Conflicts: xfreerdp

%description -n xfreerdp%pkgsuffix
xfreerdp is a client for Remote Desktop Protocol (RDP), used in a number of
Microsoft products.

This package contains X11 UI.

%package -n dfreerdp%pkgsuffix
Summary: Remote Desktop Protocol client (compatibility version)
Group: Networking/Remote access
Provides: dfbfreerdp
Requires: lib%name = %EVR
Conflicts: dfreerdp

%description -n dfreerdp%pkgsuffix
dfbfreerdp is a client for Remote Desktop Protocol (RDP), used in a number of
Microsoft products.

This package contains DirectFB UI.

%package -n lib%name
Summary: Core libraries implementing the RDP protocol (compatibility version)
Group: System/Libraries
Conflicts: lib%name

%description -n lib%name
libfreerdp can be embedded in applications.

%package -n lib%name-server
Summary: Remote Desktop Viewer server library (compatibility version)
Group: System/Libraries
Conflicts: lib%name-server

%description -n lib%name-server
FreeRDP is a client-side implementation of the Remote Desktop Protocol (RDP)
following the Microsoft Open Specifications. This package provides the shared
libraries used by the server.

%prep
%setup -n freerdp-%version
%patch1 -p1

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release \
    -DBUILD_SHARED_LIBS=ON \
    -DCMAKE_SKIP_RPATH=FALSE \
    -DCMAKE_SKIP_INSTALL_RPATH=TRUE \
    -DWITH_ALSA=ON \
    -DWITH_CAIRO=ON \
    -DWITH_CUPS=ON \
    -DWITH_CHANNELS=ON \
    -DBUILTIN_CHANNELS=OFF \
    -DWITH_CLIENT_CHANNELS=ON \
    -DWITH_CLIENT=ON \
    %{?_without_directfb:-DWITH_DIRECTFB=OFF} \
    %{?_without_ffmpeg:-DWITH_FFMPEG=OFF} \
%if_with x264
    -DWITH_X264=ON \
%else
    -DWITH_X264=OFF \
%endif
    -DWITH_GSM=ON \
    %{?_without_gss:-DWITH_GSSAPI=OFF} \
    -DWITH_FAAC=ON \
    -DWITH_FAAD2=ON \
    -DWITH_GSTREAMER_1_0=ON \
    -DGSTREAMER_1_0_INCLUDE_DIRS=%{_includedir}/gstreamer-1.0 \
    -DWITH_ICU=ON \
    -DWITH_IPP=OFF \
    -DWITH_JPEG=ON \
    -DWITH_LAME=ON \
    -DWITH_LIBRARY_VERSIONING=ON \
    -DWITH_MANPAGES=ON \
    -DWITH_MBEDTLS=ON \
    -DWITH_OPENH264=OFF \
    -DWITH_OPENSSL=ON \
    -DWITH_PCSC=ON \
    -DWITH_PULSE=ON \
    -DWITH_SERVER=ON \
    -DCHANNEL_URBDRC=ON \
    -DCHANNEL_URBDRC_CLIENT=ON \
    -DWITH_SHADOW_X11=ON \
    -DWITH_SHADOW_MAC=ON \
    -DWITH_SOXR=ON \
    -DWITH_WAYLAND=ON \
    -DWITH_X11=ON \
    -DWITH_XCURSOR=ON \
    -DWITH_XEXT=ON \
    -DWITH_XI=ON \
    -DWITH_XINERAMA=ON \
    -DWITH_XKBFILE=ON \
    -DWITH_XRENDER=ON \
    -DWITH_XTEST=ON \
    -DWITH_XV=ON \
    -DWITH_ZLIB=ON \
%ifarch x86_64
    -DWITH_SSE2=ON \
    -DWITH_VAAPI=%{?_with_ffmpeg:ON}%{?!_with_ffmpeg:OFF} \
%else
    -DWITH_SSE2=OFF \
%endif
%ifarch armh
    -DARM_FP_ABI=hard \
    -DWITH_NEON=OFF \
%endif
    #

%cmake_build

%install
%cmakeinstall_std

rm -rf %buildroot%_libdir/*.a \
       %buildroot%_libdir/freerdp/*.a \
       %buildroot%_includedir \
       %buildroot%_libdir/cmake \
       %buildroot%_libdir/pkgconfig \
       %buildroot%_libdir/*.so

%files

%files -n xfreerdp%pkgsuffix
%_bindir/xfreerdp
%_bindir/freerdp-shadow
%_man1dir/xfreerdp*

%if_with directfb
%files -n dfreerdp%pkgsuffix
%_bindir/dfreerdp
%endif

%files -n lib%name
%doc LICENSE README ChangeLog
%_libdir/lib*.so.*
%exclude %_libdir/libfreerdp-server.so.*

%files -n lib%name-server
%_libdir/libfreerdp-server.so.*

%changelog
* Mon Dec 09 2019 Andrey Cherepanov <cas@altlinux.org> 1.2.0-alt2.M80C.1
- Backport to c8 branch.

* Fri Dec 06 2019 Andrey Cherepanov <cas@altlinux.org> 1.2.0-alt1
- Compatibility version of the FreeRDP client libraries.
